#include <gnome.h>


void
on_Quitter_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button2_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button4_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_verifconfig_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button7_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_DoScan_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_scanQuit_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_cfgsave_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_PistesVideo_row_activated           (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data);

gboolean
on_PistesVideo_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_PistesVideo_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_CalculQualite_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_avCancel_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_Encoder_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_PistesAudio_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_SousTitres_button_release_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_ViewPiste_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_UseMenu_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_ToDvd9_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_PistesAudio_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_SousTitres_button_release_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_SousTitres_button_release_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_Pause_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_Dvd95_destroy_event                 (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_Dvd95_destroy                       (GtkObject       *object,
                                        gpointer         user_data);

void
on_propriete_destroy                   (GtkObject       *object,
                                        gpointer         user_data);

void
on_Scanning_destroy                    (GtkObject       *object,
                                        gpointer         user_data);

void
on_choixiso_clicked                    (GtkButton       *button,
                                        gpointer         user_data);
